@@ -118,7 +118,7 @@ impl<'de> dec::Decode<'de> for Value {
     }
 }
 
-#[cfg(feature = "serde1-value")]
+#[cfg(feature = "serde1")]
 impl serde::Serialize for Value {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
@@ -153,7 +153,7 @@ impl serde::Serialize for Value {
     }
 }
 
-#[cfg(feature = "serde1-value")]
+#[cfg(feature = "serde1")]
 impl<'de> serde::Deserialize<'de> for Value {
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
