@@ -177,7 +177,7 @@ impl TypeNum {
     }
 
     #[inline]
-    pub(crate) fn decode_u8<'a, R: Read<'a>>(self, reader: &mut R) -> Result<u8, Error<R::Error>> {
+    pub fn decode_u8<'a, R: Read<'a>>(self, reader: &mut R) -> Result<u8, Error<R::Error>> {
         match self.byte & self.major_limit {
             x @ 0 ..= 0x17 => Ok(x),
             0x18 => pull_one(reader),
@@ -286,11 +286,12 @@ macro_rules! decode_ix {
                         },
                         major::NEGATIVE => {
                             let v = TypeNum::new(!(major::NEGATIVE << 5), byte).$decode_fn(reader)?;
-                            let v = v.checked_add(1)
-                                .ok_or(Error::Overflow { name: stringify!($t) })?;
                             let v = <$t>::try_from(v)
                                 .map_err(Error::CastOverflow)?;
-                            Ok(-v)
+                            let v = -v;
+                            let v = v.checked_sub(1)
+                                .ok_or(Error::Overflow { name: stringify!($t) })?;
+                            Ok(v)
                         },
                         _ => Err(Error::TypeMismatch {
                             name: stringify!($t),
@@ -836,7 +837,7 @@ impl<'a> Decode<'a> for IgnoredAny {
                 }
             },
             major @ major::TAG => {
-                let _tag = TypeNum::new(!(major << 5), byte).decode_u8(reader)?;
+                let _tag = TypeNum::new(!(major << 5), byte).decode_u64(reader)?;
                 let _ignore = IgnoredAny::decode(reader)?;
             },
             major::SIMPLE => match byte {
